CA04-Cl11
open | /cms/logout/ |
open | /admin/ |
type | id_username | admin
type | id_password | admin
clickAndWait | //input[@value='Iniciar sesión'] |
clickAndWait | link=Portal links |
clickAndWait | link=Añadir portal link |
type | id_name_es | Ca04-Cl11
type | id_external_url | this is not an url
select | id_category | label=Primary link
clickAndWait | _continue |
verifyTextPresent | Por favor, corrija los siguientes errores. |
verifyTextPresent | Introduzca una URL válida. |
type | id_order | this is not an order
clickAndWait | _continue |
verifyTextPresent | Por favor, corrija los siguientes errores. |
verifyTextPresent | Introduzca un número entero. |
clickAndWait | link=Terminar sesión |